@@ -95,12 +95,17 @@ class KCONTACTS_EXPORT Addressee
     Q_PROPERTY(QDateTime revision READ revision)
     Q_PROPERTY(QString sortString READ sortString WRITE setSortString)
     Q_PROPERTY(KContacts::ResourceLocatorUrl url READ url WRITE setUrl)
+    Q_PROPERTY(QList<KContacts::ResourceLocatorUrl> extraUrls READ extraUrlList WRITE setExtraUrlList)
     Q_PROPERTY(QString realName READ realName)
     Q_PROPERTY(QString assembledName READ assembledName)
     Q_PROPERTY(QString preferredEmail READ preferredEmail)
+    Q_PROPERTY(QList<KContacts::Email> emails READ emailList WRITE setEmailList)
+    Q_PROPERTY(QList<KContacts::PhoneNumber> phoneNumbers READ phoneNumbers WRITE setPhoneNumbers)
+    Q_PROPERTY(QList<KContacts::Address> addresses READ addresses)
     Q_PROPERTY(QStringList categories READ categories WRITE setCategories)
     Q_PROPERTY(QStringList customs READ customs)
     Q_PROPERTY(bool changed READ changed WRITE setChanged)
+    Q_PROPERTY(QList<KContacts::Impp> impps READ imppList WRITE setImppList)
     Q_PROPERTY(QDate anniversary READ anniversary WRITE setAnniversary)
     Q_PROPERTY(QString assistantsName READ assistantsName WRITE setAssistantsName)
     Q_PROPERTY(QUrl blogFeed READ blogFeed WRITE setBlogFeed)
@@ -110,13 +115,6 @@ class KCONTACTS_EXPORT Addressee
     Q_PROPERTY(QString spousesName READ spousesName WRITE setSpousesName)
     Q_PROPERTY(KContacts::Picture photo READ photo WRITE setPhoto)
 
-    // using variants for QML compatibility, can be changed to proper types once QML supports that
-    Q_PROPERTY(QVariantList emails READ emailsVariant WRITE setEmailsVariant)
-    Q_PROPERTY(QVariantList phoneNumbers READ phoneNumbersVariant WRITE setPhoneNumbersVariant)
-    Q_PROPERTY(QVariantList addresses READ addressesVariant)
-    Q_PROPERTY(QVariantList urls READ urlsVariant)
-    Q_PROPERTY(QVariantList impps READ imppsVariant WRITE setImppsVariant)
-
     // ### the following properties are still missing:
     // - logos, photos, sounds
     // - keys
@@ -130,18 +128,6 @@ public:
      */
     typedef AddresseeList List;
 
-#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
-    /**
-      A map from unique identifier to addressee.
-
-      @deprecated Since 5.88, as it's not used anywhere.
-
-      @see uid()
-     */
-    KCONTACTS_DEPRECATED_VERSION(5, 88, "Deprecated, not used anywhere.")
-    typedef QHash<QString, Addressee> Map;
-#endif
-
     /**
       Construct an empty address book entry.
      */
@@ -750,22 +736,6 @@ public:
      */
     QString fullEmail(const QString &email = QString()) const;
 
-#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
-    /**
-      Insert an email address. If the email address already exists in this
-      addressee it is not duplicated.
-
-      @param email Email address
-      @param preferred Set to true, if this is the preferred email address of
-                       the addressee.
-
-      @deprecated Since 5.88, use addEmail(const Email &) instead; you can use the Email
-      methods to set any parameters, e.g. Email::setPreferred(), Email::setType() ...etc
-     */
-    KCONTACTS_DEPRECATED_VERSION(5, 88, "Use addEmail(const Email &), and the Email class setter methods instead.")
-    void insertEmail(const QString &email, bool preferred = false, const QMap<QString, QStringList> &param = QMap<QString, QStringList>());
-#endif
-
     /**
       Adds an email address. If the email address (i.e. @p email.mail()) already
       exists in this addressee it won't be duplicated, instead @p email is assigned
@@ -1111,8 +1081,8 @@ public:
 
     // Source
     void insertSourceUrl(const QUrl &url);
-    void setSourcesUrlList(const QVector<QUrl> &urlList);
-    QVector<QUrl> sourcesUrlList() const;
+    void setSourcesUrlList(const QList<QUrl> &urlList);
+    QList<QUrl> sourcesUrlList() const;
 
     // Impp
     Impp::List imppList() const;
@@ -1222,14 +1192,6 @@ public:
 
 private:
     KCONTACTS_NO_EXPORT void setBirthdayProperty(const QDateTime &birthday);
-    KCONTACTS_NO_EXPORT QVariantList emailsVariant() const;
-    KCONTACTS_NO_EXPORT void setEmailsVariant(const QVariantList &emails);
-    KCONTACTS_NO_EXPORT QVariantList phoneNumbersVariant() const;
-    KCONTACTS_NO_EXPORT void setPhoneNumbersVariant(const QVariantList &emails);
-    KCONTACTS_NO_EXPORT QVariantList addressesVariant() const;
-    KCONTACTS_NO_EXPORT QVariantList urlsVariant() const;
-    KCONTACTS_NO_EXPORT QVariantList imppsVariant() const;
-    KCONTACTS_NO_EXPORT void setImppsVariant(const QVariantList &impps);
 
     class Private;
     QSharedDataPointer<Private> d;
@@ -1239,7 +1201,4 @@ KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Addressee &);
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, Addressee &);
 }
 
-#define KCONTACTS_ADDRESSEE_METATYPE_DEFINED 1
-Q_DECLARE_METATYPE(KContacts::Addressee)
-
 #endif
