@@ -21,16 +21,16 @@
 
 #include "ldifconverter.h"
 #include "address.h"
-#include "addressee.h"
 #include "kcontacts_debug.h"
 #include "vcardconverter.h"
 
 #include "ldif_p.h"
 
+#include <KCountry>
 #include <KLocalizedString>
 
+#include <QIODevice>
 #include <QStringList>
-#include <QTextCodec>
 #include <QTextStream>
 
 using namespace KContacts;
@@ -91,7 +91,7 @@ bool LDIFConverter::contactGroupToLDIF(const ContactGroup &contactGroup, QString
         return false;
     }
     QTextStream t(&str, QIODevice::WriteOnly | QIODevice::Append);
-    t.setCodec(QTextCodec::codecForName("UTF-8"));
+
     t << "objectclass: top\n";
     t << "objectclass: groupOfNames\n";
 
@@ -107,34 +107,36 @@ bool LDIFConverter::contactGroupToLDIF(const ContactGroup &contactGroup, QString
 
 bool LDIFConverter::contactGroupToLDIF(const ContactGroup::List &contactGroupList, QString &str)
 {
-    if (contactGroupList.count() <= 0) {
+    if (contactGroupList.isEmpty()) {
         return false;
     }
 
     bool result = true;
-    ContactGroup::List::ConstIterator it;
-    const ContactGroup::List::ConstIterator end(contactGroupList.constEnd());
-    for (it = contactGroupList.constBegin(); it != end; ++it) {
-        result = (contactGroupToLDIF(*it, str) || result); // order matters
+    for (const ContactGroup &group : contactGroupList) {
+        result = (contactGroupToLDIF(group, str) || result); // order matters
     }
     return result;
 }
 
 bool LDIFConverter::addresseeToLDIF(const AddresseeList &addrList, QString &str)
 {
-    if (addrList.count() <= 0) {
+    if (addrList.isEmpty()) {
         return false;
     }
 
     bool result = true;
-    AddresseeList::ConstIterator it;
-    const AddresseeList::ConstIterator end(addrList.constEnd());
-    for (it = addrList.constBegin(); it != end; ++it) {
-        result = (addresseeToLDIF(*it, str) || result); // order matters
+    for (const Addressee &addr : addrList) {
+        result = (addresseeToLDIF(addr, str) || result); // order matters
     }
     return result;
 }
 
+static QString countryName(const QString &isoCodeOrName)
+{
+    const auto c = KCountry::fromAlpha2(isoCodeOrName);
+    return c.isValid() ? c.name() : isoCodeOrName;
+}
+
 bool LDIFConverter::addresseeToLDIF(const Addressee &addr, QString &str)
 {
     if (addr.isEmpty()) {
@@ -142,7 +144,6 @@ bool LDIFConverter::addresseeToLDIF(const Addressee &addr, QString &str)
     }
 
     QTextStream t(&str, QIODevice::WriteOnly | QIODevice::Append);
-    t.setCodec(QTextCodec::codecForName("UTF-8"));
 
     const Address homeAddr = addr.address(Address::Home);
     const Address workAddr = addr.address(Address::Work);
@@ -199,7 +200,7 @@ bool LDIFConverter::addresseeToLDIF(const Addressee &addr, QString &str)
     ldif_out(t, QStringLiteral("mozillahomelocalityname"), homeAddr.locality()); // Netscape 7
     ldif_out(t, QStringLiteral("mozillahomestate"), homeAddr.region());
     ldif_out(t, QStringLiteral("mozillahomepostalcode"), homeAddr.postalCode());
-    ldif_out(t, QStringLiteral("mozillahomecountryname"), Address::ISOtoCountry(homeAddr.country()));
+    ldif_out(t, QStringLiteral("mozillahomecountryname"), countryName(homeAddr.country()));
     ldif_out(t, QStringLiteral("locality"), workAddr.locality());
     ldif_out(t, QStringLiteral("streetaddress"), workAddr.street()); // Netscape 4.x
 
@@ -211,9 +212,9 @@ bool LDIFConverter::addresseeToLDIF(const Addressee &addr, QString &str)
     if (streetsCount > 1) {
         ldif_out(t, QStringLiteral("mozillaworkstreet2"), streets.at(1));
     }
-    ldif_out(t, QStringLiteral("countryname"), Address::ISOtoCountry(workAddr.country()));
+    ldif_out(t, QStringLiteral("countryname"), countryName(workAddr.country()));
     ldif_out(t, QStringLiteral("l"), workAddr.locality());
-    ldif_out(t, QStringLiteral("c"), Address::ISOtoCountry(workAddr.country()));
+    ldif_out(t, QStringLiteral("c"), countryName(workAddr.country()));
     ldif_out(t, QStringLiteral("st"), workAddr.region());
 
     ldif_out(t, QStringLiteral("title"), addr.title());
@@ -261,11 +262,13 @@ bool LDIFConverter::LDIFToAddressee(const QString &str, AddresseeList &addrList,
         return true;
     }
 
-    bool endldif = false, end = false;
+    bool endldif = false;
+    bool end = false;
     Ldif ldif;
     Ldif::ParseValue ret;
     Addressee a;
-    Address homeAddr, workAddr;
+    Address homeAddr;
+    Address workAddr;
     int birthday = -1;
     int birthmonth = -1;
     int birthyear = -1;
@@ -349,7 +352,7 @@ void KContacts::evaluatePair(Addressee &a,
     }
 
     if (fieldname.isEmpty() && !a.note().isEmpty()) {
-        // some LDIF export filters are borken and add additional
+        // some LDIF export filters are broken and add additional
         // comments on stand-alone lines. Just add them to the notes for now.
         a.setNote(a.note() + QLatin1Char('\n') + value);
         return;
@@ -380,7 +383,7 @@ void KContacts::evaluatePair(Addressee &a,
         || fieldname == QLatin1String("mozillasecondemail") /* mozilla */
         || fieldname == QLatin1String("othermailbox") /*TheBat!*/) {
         if (a.emails().indexOf(value) == -1) {
-            a.insertEmail(value);
+            a.addEmail(value);
         }
         return;
     }
@@ -525,7 +528,7 @@ void KContacts::evaluatePair(Addressee &a,
 
     if (fieldname == QLatin1String("mozillahomecountryname")) { // mozilla
         if (value.length() <= 2) {
-            value = Address::ISOtoCountry(value);
+            value = countryName(value);
         }
         homeAddr.setCountry(value);
         return;
@@ -544,7 +547,7 @@ void KContacts::evaluatePair(Addressee &a,
     if (fieldname == QLatin1String("countryname") //
         || fieldname == QLatin1Char('c')) { // mozilla
         if (value.length() <= 2) {
-            value = Address::ISOtoCountry(value);
+            value = countryName(value);
         }
         workAddr.setCountry(value);
         return;
@@ -573,18 +576,19 @@ void KContacts::evaluatePair(Addressee &a,
     if (fieldname == QLatin1String("member")) {
         // this is a mozilla list member (cn=xxx, mail=yyy)
         const QStringList list = value.split(QLatin1Char(','));
-        QString name, email;
+        QString name;
+        QString email;
 
-        QStringList::ConstIterator it;
-        const QStringList::ConstIterator end(list.constEnd());
-        for (it = list.constBegin(); it != end; ++it) {
-            if ((*it).startsWith(QLatin1String("cn="))) {
-                name = (*it).mid(3).trimmed();
-            }
-            if ((*it).startsWith(QLatin1String("mail="))) {
-                email = (*it).mid(5).trimmed();
+        const QLatin1String cnTag("cn=");
+        const QLatin1String mailTag("mail=");
+        for (const auto &str : list) {
+            if (str.startsWith(cnTag)) {
+                name = QStringView(str).mid(cnTag.size()).trimmed().toString();
+            } else if (str.startsWith(mailTag)) {
+                email = QStringView(str).mid(mailTag.size()).trimmed().toString();
             }
         }
+
         if (!name.isEmpty() && !email.isEmpty()) {
             email = QLatin1String(" <") + email + QLatin1Char('>');
         }
@@ -632,7 +636,8 @@ void KContacts::evaluatePair(Addressee &a,
         return;
     }
     if (fieldname == QLatin1String("xbatbirthday")) {
-        QDate dt = QDate::fromString(value, QStringLiteral("yyyyMMdd"));
+        const QStringView str{value};
+        QDate dt(str.mid(0, 4).toInt(), str.mid(4, 2).toInt(), str.mid(6, 2).toInt());
         if (dt.isValid()) {
             a.setBirthday(dt);
         }
